==> rocsparse_5.7.1.orig.tar.gz: rocSPARSE-rocm-5.7.1/clients/testings/testing_csr2dense.cpp <==
/*! \file */
/* ************************************************************************
 * Copyright (C) 2020-2022 Advanced Micro Devices, Inc. All rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * ************************************************************************ */
#include "testing.hpp"

#include "testing_csx2dense.hpp"

template <typename T>
void testing_csr2dense_bad_arg(const Arguments& arg)
{
    testing_csx2dense_bad_arg<rocsparse_direction_row, T>(arg, rocsparse_csr2dense<T>);
}

template <typename T>
void testing_csr2dense(const Arguments& arg)
{
    testing_csx2dense<rocsparse_direction_row, T>(
        arg, rocsparse_csr2dense<T>, rocsparse_dense2csr<T>);
}

#define INSTANTIATE(TYPE)                                                \
    template void testing_csr2dense_bad_arg<TYPE>(const Arguments& arg); \
    template void testing_csr2dense<TYPE>(const Arguments& arg)
INSTANTIATE(float);
INSTANTIATE(double);
INSTANTIATE(rocsparse_float_complex);
INSTANTIATE(rocsparse_double_complex);
void testing_csr2dense_extra(const Arguments& arg) {}

==> rocsparse_7.1.0.orig.tar.gz: rocSPARSE-rocm-7.1.0/clients/testings/testing_csr2dense.cpp <==
/*! \file */
/* ************************************************************************
 * Copyright (C) 2020-2023 Advanced Micro Devices, Inc. All rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * ************************************************************************ */
#include "testing.hpp"

#include "testing_csx2dense.hpp"

template <typename T>
void testing_csr2dense_bad_arg(const Arguments& arg)
{
    testing_csx2dense_bad_arg<rocsparse_direction_row, T>(arg);
}

template <typename T>
void testing_csr2dense(const Arguments& arg)
{
    testing_csx2dense<rocsparse_direction_row, T>(
        arg,
        (testing::rocsparse_csr2dense<T,
                                      rocsparse_int&,
                                      rocsparse_int&,
                                      rocsparse_mat_descr&,
                                      const T*,
                                      rocsparse_int*,
                                      rocsparse_int*,
                                      T*,
                                      rocsparse_int&>),
        rocsparse_dense2csr<T>);
}

#define INSTANTIATE(TYPE)                                                \
    template void testing_csr2dense_bad_arg<TYPE>(const Arguments& arg); \
    template void testing_csr2dense<TYPE>(const Arguments& arg)
INSTANTIATE(float);
INSTANTIATE(double);
INSTANTIATE(rocsparse_float_complex);
INSTANTIATE(rocsparse_double_complex);
void testing_csr2dense_extra(const Arguments& arg) {}
